==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ka_GE.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "გალერეა",
    "There was a problem reading files from this album" : "ამ ალბომიდან ფაილების წაკითხვისას წარმოიშვა პრობლემა",
    "Aborting preview. Could not find the file" : "წინასწარი ჩვენების შეჩერება. ფაილი ვერ იქნა ნაპოვნი",
    "Could not move \"{file}\", target exists" : "ფაილის \"{file}\" გადატანა ვერ მოხერხდა, დანიშნულება არსებობს",
    "Could not move \"{file}\"" : "ფაილის \"{file}\" გადატანა ვერ მოხერხდა",
    "No compatible server found at {remote}" : "თავსებადი სერვერი {remote}-ზე ვერ იქნა ნაპოვნი",
    "Invalid server url" : "არასწორი სერვერის მისამართი",
    "Could not load the description" : "აღწერილობა ვერ ჩაიტვირთა",
    "Could not load the description: " : "აღწერილობა ვერ ჩაიტვირთა:",
    "Copyright" : "საავტორო უფლებები",
    "Could not load the copyright notice: " : "საავტორო უფლებების შენიშვნის ჩატვირთვა ვერ მოხერხდა:",
    "Copyright notice" : "საავტორო უფლებების შენიშვნა",
    "Link to copyright document" : "ბმული საავტორო უფლებების დოკუმენტზე",
    "This application may not work properly on your browser." : "თქვენს ბრაუზერზე ამ აპლიკაციამ შეიძლება სწორად არ იმუშაოს.",
    "For an improved experience, please install one of the following alternatives" : "უკეთესი მოქმედებისთვის, გთხოვთ დააყენოთ ერთ-ერთი შემდეგი ალტერნატივებიდან",
    "Your browser is not supported!" : "თქვენი ბრაუზერი არაა მხარდაჭერილი!",
    "please install one of the following alternatives" : "გთხოვთ დააყენოთ შემდეგი ალტერნატივებიდან ერთ-ერთი",
    "Album cannot be shown" : "ალბომის ჩვენება ვერ ხერხდება",
    "No media files found" : "ვერც ერთი მედია ფაილი ვერ იქნა ნაპოვნი",
    "Upload pictures in the Files app to display them here" : "აქ ჩვენებისათვის ატვირთეთ სურათები ფაილების აპლიკაციაში",
    "Upload new files via drag and drop or by using the [+] button above" : "ატვირთეთ ახალი ფაილები გადატანითა და გაშვებით ან ზემოთ მყოფი [+] ღილაკის საშუალებით",
    "Configuration error" : "კონფიგურაციის შეცდომა",
    "New" : "ახალი",
    "Hide Album" : "ალბომის დამალვა",
    "Could not hide album" : "ალბომის დამალვა ვერ მოხერხდა",
    "Error loading slideshow template" : "სლაიდშოუს შაბლონის ჩატვირთვისას წარმოიშვა შეცდომა",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>შეცდომა</strong> ამ ფაილის პრევიუ ვერ დაგენერირდა.<br>სანამ სლაიდშოუდან ამოვიღებთ ამ სურათს, გთხოვთ გადახვიდეთ შემდეგ სლაიდზე",
    "Next" : "შემდეგი",
    "Play" : "დაკვრა",
    "Pause" : "პაუზა",
    "Previous" : "წინა",
    "Close" : "დახურვა",
    "Download" : "ჩამოტვირთვა",
    "Toggle background" : "ფონის გადართვა",
    "Delete" : "წაშლა",
    "Share" : "გაზიარება",
    "Could not create file \"{file}\" because it already exists" : "ფაილის \"{file}\" შექმნა ვერ მოხერხდა, ის უკვე არსებობს",
    "Could not create file \"{file}\"" : "ფაილის \"{file}\" შექმნა ვერ მოხერხდა.",
    "\"{name}\" is an invalid file name." : "\"{name}\" ფაილის არასწორი სახელია.",
    "File name cannot be empty." : "ფაილის სახელი არ შეიძლება იყოს ცარიელი.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" არაა ნებადართული ფაილის ტიპი",
    "Upload" : "ატვირთვა",
    "Error" : "შეცდომა",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "Error while unsharing" : "შეცდომა გაზიარების გაუქმების დროს",
    "Error while changing permissions" : "შეცდომა უფლებების ცვლილების დროს",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner} მომხმარებლის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner} მომხმარებლის მიერ",
    "Share with users or groups …" : "გაზიარება მომხმარებლებთან ან ჯგუფებთან …",
    "Share with users, groups or remote users …" : "გაზიარება მოხმარებლებთან, ჯგუფებთან ან დისტანციურ მოხმარებლებთან …",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "გაზიარება ადამიანებთან სხვა სერვერებზე მათი ფედერალური ქლაუდ ID-ების username@example.com/cloud მეშვეობით",
    "Share link" : "ბმულის გაზიარება",
    "The public link will expire no later than {days} days after it is created" : "ეს საზოგადო ბმული გაუქმედაბა მისი შექმნიდან არა უგვიანეს {days} დღისა",
    "Link" : "ბმული",
    "Password protect" : "პაროლით დაცვა",
    "Password" : "პაროლი",
    "Choose a password for the public link" : "საზოგადო ბმულისთვის აირჩიეთ პაროლი",
    "Allow editing" : "შეცვლის ნების დართვა",
    "Email link to person" : "ბმულის პიროვნების ელ-მისამართზე გაგზავნა",
    "Send" : "გაგზავნა",
    "Set expiration date" : "მიუთითე ვადის გასვლის დრო",
    "Expiration" : "ვადის გასვლის დრო",
    "Expiration date" : "ვადის გასვლის დრო",
    "This list is maybe truncated - please refine your search term to see more results." : "ეს სია შეიძლება იყოს წაკვეთილი - მეტი შედეგისთვის, გთხოვთ გაწმინდოთ თქვენი საძიებო სიტყვა.",
    "No users or groups found for {search}" : "მომხმარებლები და ჯგუფები {search}-ისთვის ვერ ნაპოვნი",
    "No users found for {search}" : "მომხმარებლები {search}-ისთვის ვერ იქნა ნაპოვნი",
    "An error occured. Please try again" : "წარმოიშვა შეცდომა. გთხოვთ სცადოთ ახლიდან.",
    "Adding user..." : "ემატება მომხმარებელი...",
    "group" : "ჯგუფი",
    "remote" : "დისტანციური",
    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
    "Error while retrieving shares" : "გაზიარებების მოპოვებისას წარმოიშვა შეცდომა",
    "Unshare" : "გაზიარების შეყვეტა",
    "notify by email" : "შეტყობინება ელ-ფოსტით",
    "can share" : "შეუძლია გაზიარება",
    "can edit" : "შეუძლია შეცვლა",
    "access control" : "წვდომის კონტროლი",
    "create" : "შექმნა",
    "change" : "ცვლილება",
    "delete" : "წაშლა",
    "Password protected" : "პაროლით დაცული",
    "Error unsetting expiration date" : "შეცდომა ვადის გასვლის მოხსნის დროს",
    "Error setting expiration date" : "შეცდომა ვადის გასვლის მითითების დროს",
    "Sending ..." : "გაგზავნა …",
    "Email sent" : "ელ-წერილი გაიგზავნა",
    "Warning" : "გაფრთხილება",
    "This share is password-protected" : "ეს გაზიარება დაცულია პაროლით",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან",
    "Sort by name" : "დალაგება სახელის მიხედვით",
    "Sort by date" : "დალაგება თარიღის მიხედვით",
    "Cancel upload" : "ატვირთვის გაუქმება",
    "Album information" : "ინფორმაცია ალბომზე",
    "File list" : "ფაილების სია",
    "Sorry, this file could not be found." : "ბოდიში, ეს ფაილი ვერ იქნა ნაპოვნი.",
    "Reasons might be:" : "შესაძლო მიზეზებია:",
    "the wrong file ID was provided" : "მოწოდებულია ფაილის არასწორი ID",
    "the file was removed" : "ფაილი გაუქმდა",
    "the file is corrupt" : "ფაილი დაზიანებულია",
    "the encryption key is missing" : "შიფრაციის გასაღები არმოყოფია",
    "Here is the error message returned by the server: " : "აქ არის შეცდომა რომელიც დააბრუნა სერვერმა:",
    "For more information, please contact your friendly Nextcloud administrator." : "მეტი ინფორმაციისთვის გთხოვთ დაუკავშირდეთ თქვენს მეგობრულ Nextcloud-ის ადმინისტრატორს.",
    "Sorry, but the server could not fulfill your request." : "ბოდიში, მაგრამ სერვერმა ვერ დააკმაყოფილა თქვენი მოთხოვნა",
    "Possible reasons for the problem:" : "პრობლემის შესაძლო მიზეზები:",
    "a conflicting app was installed" : "დაყენებულ იქნა კონფლიკტური აპლიკაცია",
    "a required component is missing or was disconnected" : "საჭირო კომპონენტი გათიშულ იქნა ან არმყოფია",
    "the filesystem is not readable" : "ფაილსისტემა არაა კითხვადი",
    "Sorry, this link doesn't seem to work anymore." : "ბოდიში, ეს ბმული აღარ მოქმედებს.",
    "the item was removed" : "ობიექტი გაუქმდა",
    "the link has expired" : "ბმულს ვადა გაუვიდა",
    "sharing is disabled" : "გაზიარება არაა მოქმედი",
    "For more information, please ask the person who has sent you this link." : "მეტი ინფრმაციისთვის, გთხოვთ ჰკითხოთ ადამიანს ვინც გამოგიგზავნათ ეს ბმული.",
    "Add to your Nextcloud" : "თქვენს Nextcloud-ში დამატება",
    "Picture view" : "სურათის ხედი",
    "Gallery view" : "გალერეის ხედი"
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ka_GE.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "გალერეა",
    "There was a problem reading files from this album" : "ამ ალბომიდან ფაილების წაკითხვისას წარმოიშვა პრობლემა",
    "Aborting preview. Could not find the file" : "წინასწარი ჩვენების შეჩერება. ფაილი ვერ იქნა ნაპოვნი",
    "Could not move \"{file}\", target exists" : "ფაილის \"{file}\" გადატანა ვერ მოხერხდა, დანიშნულება არსებობს",
    "Could not move \"{file}\"" : "ფაილის \"{file}\" გადატანა ვერ მოხერხდა",
    "No compatible server found at {remote}" : "თავსებადი სერვერი {remote}-ზე ვერ იქნა ნაპოვნი",
    "Invalid server url" : "არასწორი სერვერის მისამართი",
    "Could not load the description" : "აღწერილობა ვერ ჩაიტვირთა",
    "Could not load the description: " : "აღწერილობა ვერ ჩაიტვირთა:",
    "Copyright" : "საავტორო უფლებები",
    "Could not load the copyright notice: " : "საავტორო უფლებების შენიშვნის ჩატვირთვა ვერ მოხერხდა:",
    "Copyright notice" : "საავტორო უფლებების შენიშვნა",
    "Link to copyright document" : "ბმული საავტორო უფლებების დოკუმენტზე",
    "This application may not work properly on your browser." : "თქვენს ბრაუზერზე ამ აპლიკაციამ შეიძლება სწორად არ იმუშაოს.",
    "For an improved experience, please install one of the following alternatives" : "უკეთესი მოქმედებისთვის, გთხოვთ დააყენოთ ერთ-ერთი შემდეგი ალტერნატივებიდან",
    "Your browser is not supported!" : "თქვენი ბრაუზერი არაა მხარდაჭერილი!",
    "please install one of the following alternatives" : "გთხოვთ დააყენოთ შემდეგი ალტერნატივებიდან ერთ-ერთი",
    "Album cannot be shown" : "ალბომის ჩვენება ვერ ხერხდება",
    "No media files found" : "ვერც ერთი მედია ფაილი ვერ იქნა ნაპოვნი",
    "Upload pictures in the Files app to display them here" : "აქ ჩვენებისათვის ატვირთეთ სურათები ფაილების აპლიკაციაში",
    "Upload new files via drag and drop or by using the [+] button above" : "ატვირთეთ ახალი ფაილები გადატანითა და გაშვებით ან ზემოთ მყოფი [+] ღილაკის საშუალებით",
    "Configuration error" : "კონფიგურაციის შეცდომა",
    "New" : "ახალი",
    "Hide Album" : "ალბომის დამალვა",
    "Could not hide album" : "ალბომის დამალვა ვერ მოხერხდა",
    "Error loading slideshow template" : "სლაიდშოუს შაბლონის ჩატვირთვისას წარმოიშვა შეცდომა",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>შეცდომა</strong> ამ ფაილის პრევიუ ვერ დაგენერირდა.<br>სანამ სლაიდშოუდან ამოვიღებთ ამ სურათს, გთხოვთ გადახვიდეთ შემდეგ სლაიდზე",
    "Next" : "შემდეგი",
    "Play" : "დაკვრა",
    "Pause" : "პაუზა",
    "Previous" : "წინა",
    "Close" : "დახურვა",
    "Download" : "ჩამოტვირთვა",
    "Toggle background" : "ფონის გადართვა",
    "Delete" : "წაშლა",
    "Share" : "გაზიარება",
    "Could not create file \"{file}\" because it already exists" : "ფაილის \"{file}\" შექმნა ვერ მოხერხდა, ის უკვე არსებობს",
    "Could not create file \"{file}\"" : "ფაილის \"{file}\" შექმნა ვერ მოხერხდა.",
    "\"{name}\" is an invalid file name." : "\"{name}\" ფაილის არასწორი სახელია.",
    "File name cannot be empty." : "ფაილის სახელი არ შეიძლება იყოს ცარიელი.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" არაა ნებადართული ფაილის ტიპი",
    "Upload" : "ატვირთვა",
    "Error" : "შეცდომა",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "Error while unsharing" : "შეცდომა გაზიარების გაუქმების დროს",
    "Error while changing permissions" : "შეცდომა უფლებების ცვლილების დროს",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner} მომხმარებლის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner} მომხმარებლის მიერ",
    "Share with users or groups …" : "გაზიარება მომხმარებლებთან ან ჯგუფებთან …",
    "Share with users, groups or remote users …" : "გაზიარება მოხმარებლებთან, ჯგუფებთან ან დისტანციურ მოხმარებლებთან …",
    "Share link" : "ბმულის გაზიარება",
    "The public link will expire no later than {days} days after it is created" : "ეს საზოგადო ბმული გაუქმედაბა მისი შექმნიდან არა უგვიანეს {days} დღისა",
    "Link" : "ბმული",
    "Password protect" : "პაროლით დაცვა",
    "Password" : "პაროლი",
    "Choose a password for the public link" : "საზოგადო ბმულისთვის აირჩიეთ პაროლი",
    "Allow editing" : "შეცვლის ნების დართვა",
    "Email link to person" : "ბმულის პიროვნების ელ-მისამართზე გაგზავნა",
    "Send" : "გაგზავნა",
    "Set expiration date" : "მიუთითე ვადის გასვლის დრო",
    "Expiration" : "ვადის გასვლის დრო",
    "Expiration date" : "ვადის გასვლის დრო",
    "This list is maybe truncated - please refine your search term to see more results." : "ეს სია შეიძლება იყოს წაკვეთილი - მეტი შედეგისთვის, გთხოვთ გაწმინდოთ თქვენი საძიებო სიტყვა.",
    "No users or groups found for {search}" : "მომხმარებლები და ჯგუფები {search}-ისთვის ვერ ნაპოვნი",
    "No users found for {search}" : "მომხმარებლები {search}-ისთვის ვერ იქნა ნაპოვნი",
    "Adding user..." : "ემატება მომხმარებელი...",
    "group" : "ჯგუფი",
    "remote" : "დისტანციური",
    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
    "Error while retrieving shares" : "გაზიარებების მოპოვებისას წარმოიშვა შეცდომა",
    "Unshare" : "გაზიარების შეყვეტა",
    "notify by email" : "შეტყობინება ელ-ფოსტით",
    "can share" : "შეუძლია გაზიარება",
    "can edit" : "შეუძლია შეცვლა",
    "access control" : "წვდომის კონტროლი",
    "create" : "შექმნა",
    "change" : "ცვლილება",
    "delete" : "წაშლა",
    "Password protected" : "პაროლით დაცული",
    "Error unsetting expiration date" : "შეცდომა ვადის გასვლის მოხსნის დროს",
    "Error setting expiration date" : "შეცდომა ვადის გასვლის მითითების დროს",
    "Email sent" : "ელ-წერილი გაიგზავნა",
    "Warning" : "გაფრთხილება",
    "Add to your Nextcloud" : "თქვენს Nextcloud-ში დამატება",
    "This share is password-protected" : "ეს გაზიარება დაცულია პაროლით",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან",
    "Sort by name" : "დალაგება სახელის მიხედვით",
    "Sort by date" : "დალაგება თარიღის მიხედვით",
    "Cancel upload" : "ატვირთვის გაუქმება",
    "Album information" : "ინფორმაცია ალბომზე",
    "File list" : "ფაილების სია",
    "Sorry, this file could not be found." : "ბოდიში, ეს ფაილი ვერ იქნა ნაპოვნი.",
    "Reasons might be:" : "შესაძლო მიზეზებია:",
    "the wrong file ID was provided" : "მოწოდებულია ფაილის არასწორი ID",
    "the file was removed" : "ფაილი გაუქმდა",
    "the file is corrupt" : "ფაილი დაზიანებულია",
    "the encryption key is missing" : "შიფრაციის გასაღები არმოყოფია",
    "Here is the error message returned by the server: " : "აქ არის შეცდომა რომელიც დააბრუნა სერვერმა:",
    "For more information, please contact your friendly Nextcloud administrator." : "მეტი ინფორმაციისთვის გთხოვთ დაუკავშირდეთ თქვენს მეგობრულ Nextcloud-ის ადმინისტრატორს.",
    "Sorry, but the server could not fulfill your request." : "ბოდიში, მაგრამ სერვერმა ვერ დააკმაყოფილა თქვენი მოთხოვნა",
    "Possible reasons for the problem:" : "პრობლემის შესაძლო მიზეზები:",
    "a conflicting app was installed" : "დაყენებულ იქნა კონფლიკტური აპლიკაცია",
    "a required component is missing or was disconnected" : "საჭირო კომპონენტი გათიშულ იქნა ან არმყოფია",
    "the filesystem is not readable" : "ფაილსისტემა არაა კითხვადი",
    "Sorry, this link doesn't seem to work anymore." : "ბოდიში, ეს ბმული აღარ მოქმედებს.",
    "the item was removed" : "ობიექტი გაუქმდა",
    "the link has expired" : "ბმულს ვადა გაუვიდა",
    "sharing is disabled" : "გაზიარება არაა მოქმედი",
    "For more information, please ask the person who has sent you this link." : "მეტი ინფრმაციისთვის, გთხოვთ ჰკითხოთ ადამიანს ვინც გამოგიგზავნათ ეს ბმული.",
    "Picture view" : "სურათის ხედი",
    "Gallery view" : "გალერეის ხედი",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "გაზიარება ადამიანებთან სხვა სერვერებზე მათი ფედერალური ქლაუდ ID-ების username@example.com/cloud მეშვეობით",
    "An error occured. Please try again" : "წარმოიშვა შეცდომა. გთხოვთ სცადოთ ახლიდან.",
    "Sending ..." : "გაგზავნა …"
},
"nplurals=1; plural=0;");
